@@ -5,27 +5,21 @@ from typing import Dict, List, Optional
 from ..llm import LLM
 from ..browser import Page, Session
 from ..llm_browser import LLMBrowser
-from .tool import ToolRegistry
-from .task import Task
-from .step import Step, TaskResult
-from .proposer import Proposer
-from .executer import Executer
-from .throttler import Throttler
+from .task import Step, TaskResult, Task, TaskExecutor
 
 
 class Agent:
     """
     Main agent interface for web automation.
 
-    Supports multi-page (with Session) and single-page (with injected Page) modes.
+    Requires a Session for browser management and page operations.
     Provides high-level execute() for autonomous task completion and low-level methods for imperative control.
     """
 
     def __init__(
         self,
         llm: LLM,
-        session: Optional[Session] = None,
-        page: Optional[Page] = None,
+        session: Session,
         action_delay: float = 1.0,
         use_screenshot: bool = True,
         selector_llm: Optional[LLM] = None,
@@ -35,8 +29,7 @@ class Agent:
 
         Args:
             llm: LLM instance for reasoning (task planning, completion checking)
-            session: Optional Session instance for multi-page support
-            page: Optional Page instance to use as initial page
+            session: Session instance for browser management
             action_delay: Delay in seconds after actions (default: 1.0)
             use_screenshot: Use screenshots with bounding boxes in LLM context (default: True)
             selector_llm: Optional separate LLM for element selection (defaults to main llm)
@@ -50,36 +43,8 @@ class Agent:
 
         self.llm_browser = LLMBrowser(session, use_screenshot)
 
-        if page is not None:
-            self.llm_browser.set_page(page)
-
-        self.tool_registry = ToolRegistry()
-        self._task_context: Optional[Task] = None
-        self.proposer: Optional[Proposer] = None
-        self.executer: Optional[Executer] = None
-
-    def _register_tools(self) -> None:
-        from .tools.browser import (
-            NavigateTool,
-            ClickTool,
-            FillTool,
-            TypeTool,
-            UploadTool,
-        )
-
-        self.tool_registry.clear()
-
-        # Always register basic tools
-        self.tool_registry.register(NavigateTool(self.llm_browser))
-        self.tool_registry.register(ClickTool(self.llm_browser))
-        self.tool_registry.register(FillTool(self.llm_browser))
-        self.tool_registry.register(TypeTool(self.llm_browser))
-
-        # Register upload tool if task context with resources exists
-        if self._task_context and self._task_context.resources:
-            self.tool_registry.register(
-                UploadTool(self.llm_browser, self._task_context)
-            )
+        self.task: Optional[Task] = None
+        self.task_executor: Optional[TaskExecutor] = None
 
     async def execute(
         self,
@@ -98,24 +63,24 @@ class Agent:
         Returns:
             TaskResult with completion status, steps, and final message
         """
-        self.set_task(task, max_steps=max_steps, resources=resources)
-
-        for i in range(max_steps):
-            step = await self.run_step()
-
-            if step.proposal.complete:
-                return TaskResult(
-                    completed=True,
-                    steps=self._task_context.steps,
-                    message=step.proposal.message,
-                )
-
-        return TaskResult(
-            completed=False,
-            steps=self._task_context.steps,
-            message=f"Task not completed after {max_steps} steps",
+        # Create task (Agent owns the task)
+        self.task = Task(
+            description=task,
+            resources=resources or {},
+            max_steps=max_steps,
         )
 
+        # Create task executor (executes the task)
+        self.task_executor = TaskExecutor(
+            task=self.task,
+            llm=self.llm,
+            llm_browser=self.llm_browser,
+            action_delay=self.action_delay,
+        )
+
+        # Run autonomous execution loop
+        return await self.task_executor.execute()
+
     def set_task(
         self,
         task: str,
@@ -130,70 +95,36 @@ class Agent:
             max_steps: Maximum steps before giving up
             resources: Optional dict of file resources (name -> path)
         """
-        # Create new task context (replaces any existing task)
-        self._task_context = Task(
-            description=task, resources=resources or {}, max_steps=max_steps
+        # Create task (Agent owns the task)
+        self.task = Task(
+            description=task,
+            resources=resources or {},
+            max_steps=max_steps,
         )
 
-        # Create throttler for pacing operations
-        throttler = Throttler(delay=self.action_delay)
-
-        # Initialize roles with shared throttler
-        self.proposer = Proposer(
-            self.llm,
-            self._task_context,
-            self.tool_registry,
-            self.llm_browser,
-            throttler,
+        # Create task executor (executes the task)
+        self.task_executor = TaskExecutor(
+            task=self.task,
+            llm=self.llm,
+            llm_browser=self.llm_browser,
+            action_delay=self.action_delay,
         )
-        self.executer = Executer(self.tool_registry, throttler)
-
-        # Register tools (including upload tool if resources available)
-        self._register_tools()
 
     async def run_step(self) -> Step:
         """
         Execute one step of the current task.
 
         Returns:
-            Step with proposal (including completion status) and execution results
+            Step with proposal and execution results
 
         Raises:
             RuntimeError: If no task is set (call set_task first)
         """
-        if self._task_context is None or self.proposer is None:
+        if self.task_executor is None:
             raise RuntimeError("No task set. Call set_task() first.")
 
-        step_num = self._task_context.step_count + 1
-        self.logger.debug(f"=== Starting Step {step_num} ===")
-
-        # Phase 1: Propose actions and check completion
-        self.logger.debug("Phase 1: Proposing actions and checking completion...")
-        proposal = await self.proposer.propose()
-        self.logger.debug(f"Complete: {proposal.complete}")
-        self.logger.debug(f"Message: {proposal.message}")
-        self.logger.debug(f"Proposed {len(proposal.actions)} action(s)")
-        for i, action in enumerate(proposal.actions, 1):
-            self.logger.debug(f"  Action {i}: {action.tool}")
-            self.logger.debug(f"    Reason: {action.reason}")
-            self.logger.debug(f"    Parameters: {action.parameters.model_dump()}")
-
-        # Phase 2: Execute actions (if any)
-        exec_results = []
-        if proposal.actions:
-            self.logger.debug("Phase 2: Executing actions...")
-            exec_results = await self.executer.execute(proposal.actions)
-            success_count = sum(1 for r in exec_results if r.success)
-            self.logger.debug(
-                f"Execution complete: {success_count}/{len(exec_results)} successful"
-            )
-
-        step = Step(proposal=proposal, executions=exec_results)
-        self._task_context.add_step(step)
-
-        self.logger.debug(f"=== Step {step_num} Complete ===\n")
-
-        return step
+        # Delegate to task executor
+        return await self.task_executor.run_step()
 
     async def open_page(self, url: Optional[str] = None) -> Page:
         """
@@ -338,5 +269,4 @@ class Agent:
         for page in list(self.llm_browser._pages.values()):
             await self.llm_browser.close_page(page)
 
-        if self.session is not None:
-            await self.session.close()
+        await self.session.close()
