@@ -4,5 +4,6 @@ from .navigate import NavigateTool
 from .click import ClickTool
 from .fill import FillTool
 from .type import TypeTool
+from .upload import UploadTool
 
-__all__ = ["NavigateTool", "ClickTool", "FillTool", "TypeTool"]
+__all__ = ["NavigateTool", "ClickTool", "FillTool", "TypeTool", "UploadTool"]
