@@ -1,11 +1,18 @@
 """Click tool for clicking elements."""
 
 from typing import Type
+from pydantic import Field
 from ...tool import Tool
-from ...schemas import ClickParams
+from ...schemas.params import ToolParams
 from ....llm_browser import LLMBrowser
 
 
+class ClickParams(ToolParams):
+    """Parameters for click action."""
+
+    element_id: str = Field(description="ID of the element to click")
+
+
 class ClickTool(Tool[ClickParams]):
     """Tool for clicking an element."""
 
