@@ -2,20 +2,7 @@
 
 from typing import Optional, List, Dict, Any
 from openai import AsyncOpenAI
-from ....llm import LLM, Tokenizer, Context
-
-# Model max token limits
-MODEL_MAX_TOKENS = {
-    "gpt-4": 8192,
-    "gpt-4-32k": 32768,
-    "gpt-4-turbo": 128000,
-    "gpt-4-turbo-preview": 128000,
-    "gpt-3.5-turbo": 4096,
-    "gpt-3.5-turbo-16k": 16384,
-    "gpt-4.1": 128000,
-    "gpt-4.1-mini": 128000,
-    "gpt-5-nano": 400000,
-}
+from ....llm import LLM, Context
 
 
 class OpenAILLM(LLM):
@@ -27,8 +14,6 @@ class OpenAILLM(LLM):
 
     def __init__(
         self,
-        tokenizer: Tokenizer,
-        max_tokens: int,
         client: AsyncOpenAI,
         model: str,
         temperature: float,
@@ -37,13 +22,11 @@ class OpenAILLM(LLM):
         Initialize OpenAILLM (use create factory instead).
 
         Args:
-            tokenizer: Tokenizer for counting tokens
-            max_tokens: Maximum token limit for prompts
             client: AsyncOpenAI client instance
             model: Model name
             temperature: Temperature for generation
         """
-        super().__init__(tokenizer, max_tokens)
+        super().__init__()
         self.model = model
         self.temperature = temperature
         self.client = client
@@ -54,16 +37,14 @@ class OpenAILLM(LLM):
         model: str = "gpt-4",
         api_key: Optional[str] = None,
         temperature: float = 1,
-        max_tokens: Optional[int] = None,
-    ) -> 'OpenAILLM':
+    ) -> "OpenAILLM":
         """
-        Create an OpenAILLM instance with automatic tokenizer and max_tokens detection.
+        Create an OpenAILLM instance.
 
         Args:
             model: Model name (e.g., "gpt-4", "gpt-3.5-turbo")
             api_key: OpenAI API key (if None, uses OPENAI_API_KEY env var)
             temperature: Temperature for generation (0.0 to 2.0)
-            max_tokens: Override max tokens (if None, auto-detect from model)
 
         Returns:
             OpenAILLM instance
@@ -72,19 +53,8 @@ class OpenAILLM(LLM):
             >>> llm = OpenAILLM.create(model="gpt-4")
             >>> response = await llm.generate("You are helpful", "Hello!")
         """
-        # Auto-create tokenizer for this model
-        from .tiktoken_tokenizer import TikTokenizer
-        tokenizer = TikTokenizer.for_model(model)
-
-        # Auto-detect max_tokens if not provided
-        if max_tokens is None:
-            max_tokens = MODEL_MAX_TOKENS.get(model)
-            if max_tokens is None:
-                raise ValueError(f"Unknown model: {model}. Please specify max_tokens manually.")
-
         client = AsyncOpenAI(api_key=api_key)
-
-        return cls(tokenizer, max_tokens, client, model, temperature)
+        return cls(client, model, temperature)
 
     def _build_user_content(self, context: Context) -> List[Dict[str, Any]] | str:
         """Build user message content, supporting both text and images.
@@ -105,21 +75,24 @@ class OpenAILLM(LLM):
                 content.append({"type": "text", "text": block.text})
 
             if block.image:
-                content.append({
-                    "type": "image_url",
-                    "image_url": {"url": block.image.to_data_url()}
-                })
+                content.append(
+                    {
+                        "type": "image_url",
+                        "image_url": {"url": block.image.to_data_url()},
+                    }
+                )
 
         return content
 
-    async def _generate(self, context: Context) -> str:
+    async def generate(self, context: Context, use_json: bool = False) -> str:
         """
-        Internal method for actual text generation using OpenAI API.
+        Generate text using OpenAI API.
 
-        Supports multimodal content (text + images).
+        Supports multimodal content (text + images) and JSON mode.
 
         Args:
             context: Context object with system, blocks (text + images), etc.
+            use_json: If True, force JSON output
 
         Returns:
             Generated text response from OpenAI
@@ -127,16 +100,26 @@ class OpenAILLM(LLM):
         # Build user content (may include images)
         user_content = self._build_user_content(context)
 
-        self.logger.info(f"Calling OpenAI API - model: {self.model}, temperature: {self.temperature}")
+        self.logger.info(
+            f"Calling OpenAI API - model: {self.model}, temperature: {self.temperature}, "
+            f"json_mode: {use_json}"
+        )
 
-        response = await self.client.chat.completions.create(
-            model=self.model,
-            messages=[
+        # Build API call kwargs
+        api_kwargs: Dict[str, Any] = {
+            "model": self.model,
+            "messages": [
                 {"role": "system", "content": context.system},
                 {"role": "user", "content": user_content},
             ],
-            temperature=self.temperature,
-        )
+            "temperature": self.temperature,
+        }
+
+        # Add JSON mode if requested
+        if use_json:
+            api_kwargs["response_format"] = {"type": "json_object"}
+
+        response = await self.client.chat.completions.create(**api_kwargs)
 
         # Log token usage if available
         if response.usage:
